/**
 * @file sip-sec-ntlm.h
 *
 * pidgin-sipe
 *
 * Copyright (C) 2009 pier11 <pier11@operamail.com>
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

SipSecContext
sip_sec_create_context__ntlm(SipSecAuthType type);

void sip_sec_init__ntlm(void);
void sip_sec_destroy__ntlm(void);

/**
 * Describes NTML messages in human readable form
 */
gchar *
sip_sec_ntlm_message_describe(SipSecBuffer buff);

/* temporarily */
void
NTOWFv2 (const char* password, const char *user, const char *domain, unsigned char *result);
